'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_OES_required_internalformat'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_OES_required_internalformat',error_checker=_errors._error_checker)
GL_ALPHA8_OES=_C('GL_ALPHA8_OES',0x803C)
GL_DEPTH24_STENCIL8_OES=_C('GL_DEPTH24_STENCIL8_OES',0x88F0)
GL_DEPTH_COMPONENT16_OES=_C('GL_DEPTH_COMPONENT16_OES',0x81A5)
GL_DEPTH_COMPONENT24_OES=_C('GL_DEPTH_COMPONENT24_OES',0x81A6)
GL_DEPTH_COMPONENT32_OES=_C('GL_DEPTH_COMPONENT32_OES',0x81A7)
GL_LUMINANCE4_ALPHA4_OES=_C('GL_LUMINANCE4_ALPHA4_OES',0x8043)
GL_LUMINANCE8_ALPHA8_OES=_C('GL_LUMINANCE8_ALPHA8_OES',0x8045)
GL_LUMINANCE8_OES=_C('GL_LUMINANCE8_OES',0x8040)
GL_RGB10_A2_EXT=_C('GL_RGB10_A2_EXT',0x8059)
GL_RGB10_EXT=_C('GL_RGB10_EXT',0x8052)
GL_RGB565_OES=_C('GL_RGB565_OES',0x8D62)
GL_RGB5_A1_OES=_C('GL_RGB5_A1_OES',0x8057)
GL_RGB8_OES=_C('GL_RGB8_OES',0x8051)
GL_RGBA4_OES=_C('GL_RGBA4_OES',0x8056)
GL_RGBA8_OES=_C('GL_RGBA8_OES',0x8058)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_cl_event'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_cl_event',error_checker=_errors._error_checker)
GL_SYNC_CL_EVENT_ARB=_C('GL_SYNC_CL_EVENT_ARB',0x8240)
GL_SYNC_CL_EVENT_COMPLETE_ARB=_C('GL_SYNC_CL_EVENT_COMPLETE_ARB',0x8241)
@_f
@_p.types(_cs.GLsync,ctypes.POINTER(_cs._cl_context),ctypes.POINTER(_cs._cl_event),_cs.GLbitfield)
def glCreateSyncFromCLeventARB(context,event,flags):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_color_subtable'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_color_subtable',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glColorSubTableEXT(target,start,count,format,type,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLint,_cs.GLint,_cs.GLsizei)
def glCopyColorSubTableEXT(target,start,x,y,width):pass



'''OpenGL extension MESA.window_pos

This module customises the behaviour of the 
OpenGL.raw.GL.MESA.window_pos to provide a more 
Python-friendly API

Overview (from the spec)
	
	In order to set the current raster position to a specific window
	coordinate with the RasterPos command, the modelview matrix, projection
	matrix and viewport must be set very carefully.  Furthermore, if the
	desired window coordinate is outside of the window's bounds one must
	rely on a subtle side-effect of the Bitmap command in order to circumvent
	frustum clipping.
	
	This extension provides a set of functions to directly set the
	current raster position, bypassing the modelview matrix, the
	projection matrix and the viewport to window mapping.  Furthermore,
	clip testing is not performed.
	
	This greatly simplifies the process of setting the current raster
	position to a specific window coordinate prior to calling DrawPixels,
	CopyPixels or Bitmap.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/MESA/window_pos.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.MESA.window_pos import *
from OpenGL.raw.GL.MESA.window_pos import _EXTENSION_NAME

def glInitWindowPosMESA():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glWindowPos2dvMESA=wrapper.wrapper(glWindowPos2dvMESA).setInputArraySize(
    'v', 2
)
glWindowPos2fvMESA=wrapper.wrapper(glWindowPos2fvMESA).setInputArraySize(
    'v', 2
)
glWindowPos2ivMESA=wrapper.wrapper(glWindowPos2ivMESA).setInputArraySize(
    'v', 2
)
glWindowPos2svMESA=wrapper.wrapper(glWindowPos2svMESA).setInputArraySize(
    'v', 2
)
glWindowPos3dvMESA=wrapper.wrapper(glWindowPos3dvMESA).setInputArraySize(
    'v', 3
)
glWindowPos3fvMESA=wrapper.wrapper(glWindowPos3fvMESA).setInputArraySize(
    'v', 3
)
glWindowPos3ivMESA=wrapper.wrapper(glWindowPos3ivMESA).setInputArraySize(
    'v', 3
)
glWindowPos3svMESA=wrapper.wrapper(glWindowPos3svMESA).setInputArraySize(
    'v', 3
)
glWindowPos4dvMESA=wrapper.wrapper(glWindowPos4dvMESA).setInputArraySize(
    'v', 4
)
glWindowPos4fvMESA=wrapper.wrapper(glWindowPos4fvMESA).setInputArraySize(
    'v', 4
)
glWindowPos4ivMESA=wrapper.wrapper(glWindowPos4ivMESA).setInputArraySize(
    'v', 4
)
glWindowPos4svMESA=wrapper.wrapper(glWindowPos4svMESA).setInputArraySize(
    'v', 4
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_VERSION_EGL_1_1'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_VERSION_EGL_1_1',error_checker=_errors._error_checker)
EGL_BACK_BUFFER=_C('EGL_BACK_BUFFER',0x3084)
EGL_BIND_TO_TEXTURE_RGB=_C('EGL_BIND_TO_TEXTURE_RGB',0x3039)
EGL_BIND_TO_TEXTURE_RGBA=_C('EGL_BIND_TO_TEXTURE_RGBA',0x303A)
EGL_CONTEXT_LOST=_C('EGL_CONTEXT_LOST',0x300E)
EGL_MAX_SWAP_INTERVAL=_C('EGL_MAX_SWAP_INTERVAL',0x303C)
EGL_MIN_SWAP_INTERVAL=_C('EGL_MIN_SWAP_INTERVAL',0x303B)
EGL_MIPMAP_LEVEL=_C('EGL_MIPMAP_LEVEL',0x3083)
EGL_MIPMAP_TEXTURE=_C('EGL_MIPMAP_TEXTURE',0x3082)
EGL_NO_TEXTURE=_C('EGL_NO_TEXTURE',0x305C)
EGL_TEXTURE_2D=_C('EGL_TEXTURE_2D',0x305F)
EGL_TEXTURE_FORMAT=_C('EGL_TEXTURE_FORMAT',0x3080)
EGL_TEXTURE_RGB=_C('EGL_TEXTURE_RGB',0x305D)
EGL_TEXTURE_RGBA=_C('EGL_TEXTURE_RGBA',0x305E)
EGL_TEXTURE_TARGET=_C('EGL_TEXTURE_TARGET',0x3081)
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSurface,_cs.EGLint)
def eglBindTexImage(dpy,surface,buffer):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSurface,_cs.EGLint)
def eglReleaseTexImage(dpy,surface,buffer):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSurface,_cs.EGLint,_cs.EGLint)
def eglSurfaceAttrib(dpy,surface,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLint)
def eglSwapInterval(dpy,interval):pass



'''OpenGL extension EXT.base_instance

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.base_instance to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/base_instance.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.base_instance import *
from OpenGL.raw.GLES2.EXT.base_instance import _EXTENSION_NAME

def glInitBaseInstanceEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDrawElementsInstancedBaseInstanceEXT.indices size not checked against count
glDrawElementsInstancedBaseInstanceEXT=wrapper.wrapper(glDrawElementsInstancedBaseInstanceEXT).setInputArraySize(
    'indices', None
)
# INPUT glDrawElementsInstancedBaseVertexBaseInstanceEXT.indices size not checked against count
glDrawElementsInstancedBaseVertexBaseInstanceEXT=wrapper.wrapper(glDrawElementsInstancedBaseVertexBaseInstanceEXT).setInputArraySize(
    'indices', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension VERSION.GL_1_3

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_1_3 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_1_3.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_1_3 import *
from OpenGL.raw.GL.VERSION.GL_1_3 import _EXTENSION_NAME

def glInitGl13VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glCompressedTexImage3D.data size not checked against imageSize
glCompressedTexImage3D=wrapper.wrapper(glCompressedTexImage3D).setInputArraySize(
    'data', None
)
# INPUT glCompressedTexImage2D.data size not checked against imageSize
glCompressedTexImage2D=wrapper.wrapper(glCompressedTexImage2D).setInputArraySize(
    'data', None
)
# INPUT glCompressedTexImage1D.data size not checked against imageSize
glCompressedTexImage1D=wrapper.wrapper(glCompressedTexImage1D).setInputArraySize(
    'data', None
)
# INPUT glCompressedTexSubImage3D.data size not checked against imageSize
glCompressedTexSubImage3D=wrapper.wrapper(glCompressedTexSubImage3D).setInputArraySize(
    'data', None
)
# INPUT glCompressedTexSubImage2D.data size not checked against imageSize
glCompressedTexSubImage2D=wrapper.wrapper(glCompressedTexSubImage2D).setInputArraySize(
    'data', None
)
# INPUT glCompressedTexSubImage1D.data size not checked against imageSize
glCompressedTexSubImage1D=wrapper.wrapper(glCompressedTexSubImage1D).setInputArraySize(
    'data', None
)
# OUTPUT glGetCompressedTexImage.img COMPSIZE(target, level) 
glMultiTexCoord1dv=wrapper.wrapper(glMultiTexCoord1dv).setInputArraySize(
    'v', 1
)
glMultiTexCoord1fv=wrapper.wrapper(glMultiTexCoord1fv).setInputArraySize(
    'v', 1
)
glMultiTexCoord1iv=wrapper.wrapper(glMultiTexCoord1iv).setInputArraySize(
    'v', 1
)
glMultiTexCoord1sv=wrapper.wrapper(glMultiTexCoord1sv).setInputArraySize(
    'v', 1
)
glMultiTexCoord2dv=wrapper.wrapper(glMultiTexCoord2dv).setInputArraySize(
    'v', 2
)
glMultiTexCoord2fv=wrapper.wrapper(glMultiTexCoord2fv).setInputArraySize(
    'v', 2
)
glMultiTexCoord2iv=wrapper.wrapper(glMultiTexCoord2iv).setInputArraySize(
    'v', 2
)
glMultiTexCoord2sv=wrapper.wrapper(glMultiTexCoord2sv).setInputArraySize(
    'v', 2
)
glMultiTexCoord3dv=wrapper.wrapper(glMultiTexCoord3dv).setInputArraySize(
    'v', 3
)
glMultiTexCoord3fv=wrapper.wrapper(glMultiTexCoord3fv).setInputArraySize(
    'v', 3
)
glMultiTexCoord3iv=wrapper.wrapper(glMultiTexCoord3iv).setInputArraySize(
    'v', 3
)
glMultiTexCoord3sv=wrapper.wrapper(glMultiTexCoord3sv).setInputArraySize(
    'v', 3
)
glMultiTexCoord4dv=wrapper.wrapper(glMultiTexCoord4dv).setInputArraySize(
    'v', 4
)
glMultiTexCoord4fv=wrapper.wrapper(glMultiTexCoord4fv).setInputArraySize(
    'v', 4
)
glMultiTexCoord4iv=wrapper.wrapper(glMultiTexCoord4iv).setInputArraySize(
    'v', 4
)
glMultiTexCoord4sv=wrapper.wrapper(glMultiTexCoord4sv).setInputArraySize(
    'v', 4
)
glLoadTransposeMatrixf=wrapper.wrapper(glLoadTransposeMatrixf).setInputArraySize(
    'm', 16
)
glLoadTransposeMatrixd=wrapper.wrapper(glLoadTransposeMatrixd).setInputArraySize(
    'm', 16
)
glMultTransposeMatrixf=wrapper.wrapper(glMultTransposeMatrixf).setInputArraySize(
    'm', 16
)
glMultTransposeMatrixd=wrapper.wrapper(glMultTransposeMatrixd).setInputArraySize(
    'm', 16
)
### END AUTOGENERATED SECTION
GL_SRC0_ALPHA = GL_SOURCE0_ALPHA # alias
GL_SRC0_RGB = GL_SOURCE0_RGB # alias
GL_SRC1_ALPHA = GL_SOURCE1_ALPHA # alias
GL_SRC1_RGB = GL_SOURCE1_RGB # alias
GL_SRC2_ALPHA = GL_SOURCE2_ALPHA # alias
GL_SRC2_RGB = GL_SOURCE2_RGB # alias

from OpenGL import wrapper
from OpenGL.raw.GL.VERSION import GL_1_3 as _simple
from OpenGL.GL import images, glget

for dimensions in (1,2,3):
    for function in ('glCompressedTexImage%sD','glCompressedTexSubImage%sD'):
        name = function%(dimensions,)
        globals()[ name ] = images.compressedImageFunction(
            getattr( _simple, name )
        )
        try:
            del name, function
        except NameError as err:
            pass
    try:
        del dimensions
    except NameError as err:
        pass

if _simple.glGetCompressedTexImage:
    def glGetCompressedTexImage( target, level, img=None ):
        """Retrieve a compressed texture image"""
        if img is None:
            length = glget.glGetTexLevelParameteriv(
                target, 0,
                _simple.GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB,
            )
            img = arrays.ArrayDataType.zeros( (length,), constants.GL_UNSIGNED_BYTE )
        return _simple.glGetCompressedTexImage(target, 0, img);



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_gpu_shader5'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_gpu_shader5',error_checker=_errors._error_checker)
GL_FRAGMENT_INTERPOLATION_OFFSET_BITS=_C('GL_FRAGMENT_INTERPOLATION_OFFSET_BITS',0x8E5D)
GL_GEOMETRY_SHADER_INVOCATIONS=_C('GL_GEOMETRY_SHADER_INVOCATIONS',0x887F)
GL_MAX_FRAGMENT_INTERPOLATION_OFFSET=_C('GL_MAX_FRAGMENT_INTERPOLATION_OFFSET',0x8E5C)
GL_MAX_GEOMETRY_SHADER_INVOCATIONS=_C('GL_MAX_GEOMETRY_SHADER_INVOCATIONS',0x8E5A)
GL_MAX_VERTEX_STREAMS=_C('GL_MAX_VERTEX_STREAMS',0x8E71)
GL_MIN_FRAGMENT_INTERPOLATION_OFFSET=_C('GL_MIN_FRAGMENT_INTERPOLATION_OFFSET',0x8E5B)




'''OpenGL extension EXT.stencil_two_side

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.stencil_two_side to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides two-sided stencil testing where the
	stencil-related state (stencil operations, reference value, compare
	mask, and write mask) may be different for front- and back-facing
	polygons.  Two-sided stencil testing may improve the performance
	of stenciled shadow volume and Constructive Solid Geometry (CSG)
	rendering algorithms.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/stencil_two_side.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.stencil_two_side import *
from OpenGL.raw.GL.EXT.stencil_two_side import _EXTENSION_NAME

def glInitStencilTwoSideEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension APPLE.rgb_422

This module customises the behaviour of the 
OpenGL.raw.GLES2.APPLE.rgb_422 to provide a more 
Python-friendly API

Overview (from the spec)
	
	A common storage format for video data is 8-bit 422, with every four
	bytes encoding two pixels.   Within the four bytes there are two
	luminance samples, and two chrominance samples that are shared between
	both pixels.
	
	There is a previous extension, namely GL_APPLE_ycbcr_422 that provided
	transparent support for this kind of data.   However, that extension
	left the exact conversion from Y'CbCr to RGB undefined.  In reality,
	it really had always been based on the ITU-R BT.601 standard, which 
	meant it was not particularly useful for dealing with high definition
	video data, which is encoded using the Rec. 709 standard.
	
	In some cases the original extension was implemented via fixed function
	hardware, but on more modern graphics processors this is done via
	a combination of 422 sampling formats and fragment shader instructions.
	
	This extension essentially exposes a "raw" 422 texture format that 
	allows developers to access the raw pre-converted Y'CbCr components
	so that they have full control over the colorspace conversion.
	
	In order to avoid defining entirely new color channels within GL,
	the Y, Cb and Cr color channels within the 422 data are mapped into
	the existing green, blue and red color channels, respectively.  Developers
	must write their own fragment shader/program to perform the desired
	color space transformation.
	
	Note: Because of the use of the packed UNSIGNED_SHORT_8_8[_REV] types, the
	correct type to use based on the layout of the data in memory (Cb Y Cr Y 
	versus Y Cb Y Cr) will necessarily be sensitive to host endianness.
	
	This extension differs from the EXT_422_pixels extension in a couple of
	ways.   First, this extension defines only a single new format, while
	relying on two new type arguments to differentiate between the two
	component orderings.  Second, this extension provides no defined method
	of filtering the chroma values between adjacent pixels.   And lastly,
	the color channel assignments are slightly different, essentially to
	match more closely the rough meanings of the Y, Cb and Cr values in 
	422 video data.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/rgb_422.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.APPLE.rgb_422 import *
from OpenGL.raw.GLES2.APPLE.rgb_422 import _EXTENSION_NAME

def glInitRgb422APPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.parameter_buffer_object

This module customises the behaviour of the 
OpenGL.raw.GL.NV.parameter_buffer_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension, in conjunction with NV_gpu_program4, provides a new type
	of program parameter than can be used as a constant during vertex,
	fragment, or geometry program execution.  Each program target has a set of
	parameter buffer binding points to which buffer objects can be attached.
	
	A vertex, fragment, or geometry program can read data from the attached
	buffer objects using a binding of the form "program.buffer[a][b]".  This
	binding reads data from the buffer object attached to binding point <a>.
	The buffer object attached is treated either as an array of 32-bit words
	or an array of four-component vectors, and the binding above reads the
	array element numbered <b>.
	
	The use of buffer objects allows applications to change large blocks of
	program parameters at once, simply by binding a new buffer object.  It
	also provides a number of new ways to load parameter values, including
	readback from the frame buffer (EXT_pixel_buffer_object), transform
	feedback (NV_transform_feedback), buffer object loading functions such as
	MapBuffer and BufferData, as well as dedicated parameter buffer update
	functions provided by this extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/parameter_buffer_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.parameter_buffer_object import *
from OpenGL.raw.GL.NV.parameter_buffer_object import _EXTENSION_NAME

def glInitParameterBufferObjectNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glProgramBufferParametersfvNV.params size not checked against count
glProgramBufferParametersfvNV=wrapper.wrapper(glProgramBufferParametersfvNV).setInputArraySize(
    'params', None
)
# INPUT glProgramBufferParametersIivNV.params size not checked against count
glProgramBufferParametersIivNV=wrapper.wrapper(glProgramBufferParametersIivNV).setInputArraySize(
    'params', None
)
# INPUT glProgramBufferParametersIuivNV.params size not checked against count
glProgramBufferParametersIuivNV=wrapper.wrapper(glProgramBufferParametersIuivNV).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_OML_swap_method'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_OML_swap_method',error_checker=_errors._error_checker)
GLX_SWAP_COPY_OML=_C('GLX_SWAP_COPY_OML',0x8062)
GLX_SWAP_EXCHANGE_OML=_C('GLX_SWAP_EXCHANGE_OML',0x8061)
GLX_SWAP_METHOD_OML=_C('GLX_SWAP_METHOD_OML',0x8060)
GLX_SWAP_UNDEFINED_OML=_C('GLX_SWAP_UNDEFINED_OML',0x8063)




'''OpenGL extension NV.register_combiners

This module customises the behaviour of the 
OpenGL.raw.GL.NV.register_combiners to provide a more 
Python-friendly API

Overview (from the spec)
	
	NVIDIA's next-generation graphics processor and its derivative
	designs support an extremely configurable mechanism know as "register
	combiners" for computing fragment colors.
	
	The register combiner mechanism is a significant redesign of NVIDIA's
	original TNT combiner mechanism as introduced by NVIDIA's RIVA
	TNT graphics processor.  Familiarity with the TNT combiners will
	help the reader appreciate the greatly enhanced register combiners
	functionality (see the NV_texture_env_combine4 OpenGL extension
	specification for this background).  The register combiner mechanism
	has the following enhanced functionality: 
	
	  The numeric range of combiner computations is from [-1,1]
	  (instead of TNT's [0,1] numeric range),
	
	  The set of available combiner inputs is expanded to include the
	  secondary color, fog color, fog factor, and a second combiner
	  constant color (TNT's available combiner inputs consist of
	  only zero, a single combiner constant color, the primary color,
	  texture 0, texture 1, and, in the case of combiner 1, the result
	  of combiner 0).
	
	  Each combiner variable input can be independently scaled and
	  biased into several possible numeric ranges (TNT can only
	  complement combiner inputs).
	
	  Each combiner stage computes three distinct outputs (instead
	  TNT's single combiner output).
	
	  The output operations include support for computing dot products
	  (TNT has no support for computing dot products).
	
	  After each output operation, there is a configurable scale and bias
	  applied (TNT's combiner operations builds in a scale and/or bias
	  into some of its combiner operations).
	
	  Each input variable for each combiner stage is fetched from any
	  entry in a combiner register set.  Moreover, the outputs of each
	  combiner stage are written into the register set of the subsequent
	  combiner stage (TNT could only use the result from combiner 0 as
	  a possible input to combiner 1; TNT lacks the notion of an
	  input/output register set).
	
	  The register combiner mechanism supports at least two general
	  combiner stages and then a special final combiner stage appropriate
	  for applying a color sum and fog computation (TNT provides two
	  simpler combiner stages, and TNT's color sum and fog stages are
	  hard-wired and not subsumed by the combiner mechanism as in register
	  combiners).
	
	The register combiners fit into the OpenGL pipeline as a rasterization
	processing stage operating in parallel to the traditional OpenGL
	texture environment, color sum, AND fog application.  Enabling this
	extension bypasses OpenGL's existing texture environment, color
	sum, and fog application processing and instead use the register
	combiners.  The combiner and texture environment state is orthogonal
	so modifying combiner state does not change the traditional OpenGL
	texture environment state and the texture environment state is
	ignored when combiners are enabled.
	
	OpenGL application developers can use the register combiner mechanism
	for very sophisticated shading techniques.  For example, an
	approximation of Blinn's bump mapping technique can be achieved with
	the combiner mechanism.  Additionally, multi-pass shading models
	that require several passes with unextended OpenGL 1.2 functionality
	can be implemented in several fewer passes with register combiners.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/register_combiners.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.register_combiners import *
from OpenGL.raw.GL.NV.register_combiners import _EXTENSION_NAME

def glInitRegisterCombinersNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glCombinerParameterfvNV.params size not checked against 'pname'
glCombinerParameterfvNV=wrapper.wrapper(glCombinerParameterfvNV).setInputArraySize(
    'params', None
)
# INPUT glCombinerParameterivNV.params size not checked against 'pname'
glCombinerParameterivNV=wrapper.wrapper(glCombinerParameterivNV).setInputArraySize(
    'params', None
)
glGetCombinerInputParameterfvNV=wrapper.wrapper(glGetCombinerInputParameterfvNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetCombinerInputParameterivNV=wrapper.wrapper(glGetCombinerInputParameterivNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetCombinerOutputParameterfvNV=wrapper.wrapper(glGetCombinerOutputParameterfvNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetCombinerOutputParameterivNV=wrapper.wrapper(glGetCombinerOutputParameterivNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetFinalCombinerInputParameterfvNV=wrapper.wrapper(glGetFinalCombinerInputParameterfvNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetFinalCombinerInputParameterivNV=wrapper.wrapper(glGetFinalCombinerInputParameterivNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.texture_multisample

This module customises the behaviour of the 
OpenGL.raw.GL.NV.texture_multisample to provide a more 
Python-friendly API

Overview (from the spec)
	
	This specification extends NV_gpu_program4 to support per-sample fetching
	from multisample textures described in ARB_texture_multisample.
	Specifically, it adds:
	
	  * The TXFMS sample fetch instruction.
	
	  * Texture targets corresponding to the multisample textures added by
	    ARB_texture_multisample.
	
	  * A program option to enable these features.
	
	This specification also extends the ARB_texture_multisample extension
	by adding support for EXT_direct_state_access and VCAA multisample
	coverage with seperate <colorSamples> and <coverageSamples> parameters.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/texture_multisample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.texture_multisample import *
from OpenGL.raw.GL.NV.texture_multisample import _EXTENSION_NAME

def glInitTextureMultisampleNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGIS.texture_select

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.texture_select to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces several new texture internal formats.  The
	purpose of these new formats is to reorganize the components of a
	texture into groups of components.  The currently selected group
	effectively becomes the internal format.
	
	Also, two new texture parameters are introduced that control the
	selection of these groups of components.
	
	For example, assume a texture internal format of DUAL_LUMINANCE4_SGIS is
	specified.  Now there are two groups of components, where each group has
	a format of LUMINANCE4.  One of the two LUMINANCE groups is always
	selected.  components can be selected and then interpreted as a LUMINANCE
	texture.
	
	The purpose of this extension is allow better utilization of texture
	memory by subdividing the internal representation of a texel into 1, 2,
	or 4 smaller texels.  Additionally, this may improve performance of
	texture downloads.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/texture_select.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIS.texture_select import *
from OpenGL.raw.GL.SGIS.texture_select import _EXTENSION_NAME

def glInitTextureSelectSGIS():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.vertex_attrib_binding

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.vertex_attrib_binding to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL currently supports (at least) 16 vertex attributes and 16 vertex 
	buffer bindings, with a fixed mapping between vertex attributes and 
	vertex buffer bindings. This extension allows the application to change
	the mapping between attributes and bindings, which can make it more 
	efficient to update vertex buffer bindings for interleaved vertex formats
	where many attributes share the same buffer.
	
	This extension also separates the vertex binding update from the vertex
	attribute format update, which saves applications the effort of 
	redundantly specifying the same format state over and over.
	
	Conceptually, this extension splits the state for generic vertex attribute
	arrays into:
	
	- An array of vertex buffer binding points, each of which specifies:
	
	  - a bound buffer object,
	
	  - a starting offset for the vertex attribute data in that buffer object,
	
	  - a stride used by all attributes using that binding point, and
	
	  - a frequency divisor used by all attributes using that binding point.
	
	- An array of generic vertex attribute format information records, each of
	  which specifies:
	
	  - a reference to one of the new buffer binding points above,
	
	  - a component count and format, and a normalization flag for the
	    attribute data, and
	
	  - the offset of the attribute data relative to the base offset of each
	    vertex found at the associated binding point.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/vertex_attrib_binding.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.vertex_attrib_binding import *
from OpenGL.raw.GL.ARB.vertex_attrib_binding import _EXTENSION_NAME

def glInitVertexAttribBindingARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_multisample'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_multisample',error_checker=_errors._error_checker)
GL_MULTISAMPLE_ARB=_C('GL_MULTISAMPLE_ARB',0x809D)
GL_MULTISAMPLE_BIT_ARB=_C('GL_MULTISAMPLE_BIT_ARB',0x20000000)
GL_SAMPLES_ARB=_C('GL_SAMPLES_ARB',0x80A9)
GL_SAMPLE_ALPHA_TO_COVERAGE_ARB=_C('GL_SAMPLE_ALPHA_TO_COVERAGE_ARB',0x809E)
GL_SAMPLE_ALPHA_TO_ONE_ARB=_C('GL_SAMPLE_ALPHA_TO_ONE_ARB',0x809F)
GL_SAMPLE_BUFFERS_ARB=_C('GL_SAMPLE_BUFFERS_ARB',0x80A8)
GL_SAMPLE_COVERAGE_ARB=_C('GL_SAMPLE_COVERAGE_ARB',0x80A0)
GL_SAMPLE_COVERAGE_INVERT_ARB=_C('GL_SAMPLE_COVERAGE_INVERT_ARB',0x80AB)
GL_SAMPLE_COVERAGE_VALUE_ARB=_C('GL_SAMPLE_COVERAGE_VALUE_ARB',0x80AA)
@_f
@_p.types(None,_cs.GLfloat,_cs.GLboolean)
def glSampleCoverageARB(value,invert):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_pipeline_statistics_query'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_pipeline_statistics_query',error_checker=_errors._error_checker)
GL_CLIPPING_INPUT_PRIMITIVES_ARB=_C('GL_CLIPPING_INPUT_PRIMITIVES_ARB',0x82F6)
GL_CLIPPING_OUTPUT_PRIMITIVES_ARB=_C('GL_CLIPPING_OUTPUT_PRIMITIVES_ARB',0x82F7)
GL_COMPUTE_SHADER_INVOCATIONS_ARB=_C('GL_COMPUTE_SHADER_INVOCATIONS_ARB',0x82F5)
GL_FRAGMENT_SHADER_INVOCATIONS_ARB=_C('GL_FRAGMENT_SHADER_INVOCATIONS_ARB',0x82F4)
GL_GEOMETRY_SHADER_INVOCATIONS=_C('GL_GEOMETRY_SHADER_INVOCATIONS',0x887F)
GL_GEOMETRY_SHADER_PRIMITIVES_EMITTED_ARB=_C('GL_GEOMETRY_SHADER_PRIMITIVES_EMITTED_ARB',0x82F3)
GL_PRIMITIVES_SUBMITTED_ARB=_C('GL_PRIMITIVES_SUBMITTED_ARB',0x82EF)
GL_TESS_CONTROL_SHADER_PATCHES_ARB=_C('GL_TESS_CONTROL_SHADER_PATCHES_ARB',0x82F1)
GL_TESS_EVALUATION_SHADER_INVOCATIONS_ARB=_C('GL_TESS_EVALUATION_SHADER_INVOCATIONS_ARB',0x82F2)
GL_VERTEX_SHADER_INVOCATIONS_ARB=_C('GL_VERTEX_SHADER_INVOCATIONS_ARB',0x82F0)
GL_VERTICES_SUBMITTED_ARB=_C('GL_VERTICES_SUBMITTED_ARB',0x82EE)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_NV_swap_group'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_NV_swap_group',error_checker=_errors._error_checker)

@_f
@_p.types(_cs.BOOL,_cs.GLuint,_cs.GLuint)
def wglBindSwapBarrierNV(group,barrier):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.GLuint)
def wglJoinSwapGroupNV(hDC,group):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,arrays.GLuintArray)
def wglQueryFrameCountNV(hDC,count):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,arrays.GLuintArray,arrays.GLuintArray)
def wglQueryMaxSwapGroupsNV(hDC,maxGroups,maxBarriers):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,arrays.GLuintArray,arrays.GLuintArray)
def wglQuerySwapGroupNV(hDC,group,barrier):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC)
def wglResetFrameCountNV(hDC):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_OES_texture_cube_map_array'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_OES_texture_cube_map_array',error_checker=_errors._error_checker)
GL_IMAGE_CUBE_MAP_ARRAY_OES=_C('GL_IMAGE_CUBE_MAP_ARRAY_OES',0x9054)
GL_INT_IMAGE_CUBE_MAP_ARRAY_OES=_C('GL_INT_IMAGE_CUBE_MAP_ARRAY_OES',0x905F)
GL_INT_SAMPLER_CUBE_MAP_ARRAY_OES=_C('GL_INT_SAMPLER_CUBE_MAP_ARRAY_OES',0x900E)
GL_SAMPLER_CUBE_MAP_ARRAY_OES=_C('GL_SAMPLER_CUBE_MAP_ARRAY_OES',0x900C)
GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW_OES=_C('GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW_OES',0x900D)
GL_TEXTURE_BINDING_CUBE_MAP_ARRAY_OES=_C('GL_TEXTURE_BINDING_CUBE_MAP_ARRAY_OES',0x900A)
GL_TEXTURE_CUBE_MAP_ARRAY_OES=_C('GL_TEXTURE_CUBE_MAP_ARRAY_OES',0x9009)
GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY_OES=_C('GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY_OES',0x906A)
GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY_OES=_C('GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY_OES',0x900F)




"""Constants for OpenGL.GLUT

Automatically generated by the generateraw script, do not edit!
"""

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL.raw.GL import _types as GL_types
GLvoid = GL_types.GLvoid



GLUT_ACCUM = Constant( 'GLUT_ACCUM', 4)
GLUT_ACTIVE_ALT = Constant( 'GLUT_ACTIVE_ALT', 4)
GLUT_ACTIVE_CTRL = Constant( 'GLUT_ACTIVE_CTRL', 2)
GLUT_ACTIVE_SHIFT = Constant( 'GLUT_ACTIVE_SHIFT', 1)
GLUT_ALPHA = Constant( 'GLUT_ALPHA', 8)
GLUT_API_VERSION = Constant( 'GLUT_API_VERSION', 4)
GLUT_BLUE = Constant( 'GLUT_BLUE', 2)
GLUT_CURSOR_BOTTOM_LEFT_CORNER = Constant( 'GLUT_CURSOR_BOTTOM_LEFT_CORNER', 19)
GLUT_CURSOR_BOTTOM_RIGHT_CORNER = Constant( 'GLUT_CURSOR_BOTTOM_RIGHT_CORNER', 18)
GLUT_CURSOR_BOTTOM_SIDE = Constant( 'GLUT_CURSOR_BOTTOM_SIDE', 13)
GLUT_CURSOR_CROSSHAIR = Constant( 'GLUT_CURSOR_CROSSHAIR', 9)
GLUT_CURSOR_CYCLE = Constant( 'GLUT_CURSOR_CYCLE', 5)
GLUT_CURSOR_DESTROY = Constant( 'GLUT_CURSOR_DESTROY', 3)
GLUT_CURSOR_FULL_CROSSHAIR = Constant( 'GLUT_CURSOR_FULL_CROSSHAIR', 102)
GLUT_CURSOR_HELP = Constant( 'GLUT_CURSOR_HELP', 4)
GLUT_CURSOR_INFO = Constant( 'GLUT_CURSOR_INFO', 2)
GLUT_CURSOR_INHERIT = Constant( 'GLUT_CURSOR_INHERIT', 100)
GLUT_CURSOR_LEFT_ARROW = Constant( 'GLUT_CURSOR_LEFT_ARROW', 1)
GLUT_CURSOR_LEFT_RIGHT = Constant( 'GLUT_CURSOR_LEFT_RIGHT', 11)
GLUT_CURSOR_LEFT_SIDE = Constant( 'GLUT_CURSOR_LEFT_SIDE', 14)
GLUT_CURSOR_NONE = Constant( 'GLUT_CURSOR_NONE', 101)
GLUT_CURSOR_RIGHT_ARROW = Constant( 'GLUT_CURSOR_RIGHT_ARROW', 0)
GLUT_CURSOR_RIGHT_SIDE = Constant( 'GLUT_CURSOR_RIGHT_SIDE', 15)
GLUT_CURSOR_SPRAY = Constant( 'GLUT_CURSOR_SPRAY', 6)
GLUT_CURSOR_TEXT = Constant( 'GLUT_CURSOR_TEXT', 8)
GLUT_CURSOR_TOP_LEFT_CORNER = Constant( 'GLUT_CURSOR_TOP_LEFT_CORNER', 16)
GLUT_CURSOR_TOP_RIGHT_CORNER = Constant( 'GLUT_CURSOR_TOP_RIGHT_CORNER', 17)
GLUT_CURSOR_TOP_SIDE = Constant( 'GLUT_CURSOR_TOP_SIDE', 12)
GLUT_CURSOR_UP_DOWN = Constant( 'GLUT_CURSOR_UP_DOWN', 10)
GLUT_CURSOR_WAIT = Constant( 'GLUT_CURSOR_WAIT', 7)
GLUT_DEPTH = Constant( 'GLUT_DEPTH', 16)
GLUT_DEVICE_IGNORE_KEY_REPEAT = Constant( 'GLUT_DEVICE_IGNORE_KEY_REPEAT', 610)
GLUT_DEVICE_KEY_REPEAT = Constant( 'GLUT_DEVICE_KEY_REPEAT', 611)
GLUT_DISPLAY_MODE_POSSIBLE = Constant( 'GLUT_DISPLAY_MODE_POSSIBLE', 400)
GLUT_DOUBLE = Constant( 'GLUT_DOUBLE', 2)
GLUT_DOWN = Constant( 'GLUT_DOWN', 0)
GLUT_ELAPSED_TIME = Constant( 'GLUT_ELAPSED_TIME', 700)
GLUT_ENTERED = Constant( 'GLUT_ENTERED', 1)
GLUT_FULLY_COVERED = Constant( 'GLUT_FULLY_COVERED', 3)
GLUT_FULLY_RETAINED = Constant( 'GLUT_FULLY_RETAINED', 1)
GLUT_GAME_MODE_ACTIVE = Constant( 'GLUT_GAME_MODE_ACTIVE', 0)
GLUT_GAME_MODE_DISPLAY_CHANGED = Constant( 'GLUT_GAME_MODE_DISPLAY_CHANGED', 6)
GLUT_GAME_MODE_HEIGHT = Constant( 'GLUT_GAME_MODE_HEIGHT', 3)
GLUT_GAME_MODE_PIXEL_DEPTH = Constant( 'GLUT_GAME_MODE_PIXEL_DEPTH', 4)
GLUT_GAME_MODE_POSSIBLE = Constant( 'GLUT_GAME_MODE_POSSIBLE', 1)
GLUT_GAME_MODE_REFRESH_RATE = Constant( 'GLUT_GAME_MODE_REFRESH_RATE', 5)
GLUT_GAME_MODE_WIDTH = Constant( 'GLUT_GAME_MODE_WIDTH', 2)
GLUT_GREEN = Constant( 'GLUT_GREEN', 1)
GLUT_HAS_DIAL_AND_BUTTON_BOX = Constant( 'GLUT_HAS_DIAL_AND_BUTTON_BOX', 603)
GLUT_HAS_JOYSTICK = Constant( 'GLUT_HAS_JOYSTICK', 612)
GLUT_HAS_KEYBOARD = Constant( 'GLUT_HAS_KEYBOARD', 600)
GLUT_HAS_MOUSE = Constant( 'GLUT_HAS_MOUSE', 601)
GLUT_HAS_OVERLAY = Constant( 'GLUT_HAS_OVERLAY', 802)
GLUT_HAS_SPACEBALL = Constant( 'GLUT_HAS_SPACEBALL', 602)
GLUT_HAS_TABLET = Constant( 'GLUT_HAS_TABLET', 604)
GLUT_HIDDEN = Constant( 'GLUT_HIDDEN', 0)
GLUT_INDEX = Constant( 'GLUT_INDEX', 1)
GLUT_INIT_DISPLAY_MODE = Constant( 'GLUT_INIT_DISPLAY_MODE', 504)
GLUT_INIT_STATE = Constant( 'GLUT_INIT_STATE', 124)
GLUT_INIT_WINDOW_HEIGHT = Constant( 'GLUT_INIT_WINDOW_HEIGHT', 503)
GLUT_INIT_WINDOW_WIDTH = Constant( 'GLUT_INIT_WINDOW_WIDTH', 502)
GLUT_INIT_WINDOW_X = Constant( 'GLUT_INIT_WINDOW_X', 500)
GLUT_INIT_WINDOW_Y = Constant( 'GLUT_INIT_WINDOW_Y', 501)
GLUT_JOYSTICK_AXES = Constant( 'GLUT_JOYSTICK_AXES', 615)
GLUT_JOYSTICK_BUTTONS = Constant( 'GLUT_JOYSTICK_BUTTONS', 614)
GLUT_JOYSTICK_BUTTON_A = Constant( 'GLUT_JOYSTICK_BUTTON_A', 1)
GLUT_JOYSTICK_BUTTON_B = Constant( 'GLUT_JOYSTICK_BUTTON_B', 2)
GLUT_JOYSTICK_BUTTON_C = Constant( 'GLUT_JOYSTICK_BUTTON_C', 4)
GLUT_JOYSTICK_BUTTON_D = Constant( 'GLUT_JOYSTICK_BUTTON_D', 8)
GLUT_JOYSTICK_POLL_RATE = Constant( 'GLUT_JOYSTICK_POLL_RATE', 616)
GLUT_KEY_DOWN = Constant( 'GLUT_KEY_DOWN', 103)
GLUT_KEY_END = Constant( 'GLUT_KEY_END', 107)
GLUT_KEY_F1 = Constant( 'GLUT_KEY_F1', 1)
GLUT_KEY_F10 = Constant( 'GLUT_KEY_F10', 10)
GLUT_KEY_F11 = Constant( 'GLUT_KEY_F11', 11)
GLUT_KEY_F12 = Constant( 'GLUT_KEY_F12', 12)
GLUT_KEY_F2 = Constant( 'GLUT_KEY_F2', 2)
GLUT_KEY_F3 = Constant( 'GLUT_KEY_F3', 3)
GLUT_KEY_F4 = Constant( 'GLUT_KEY_F4', 4)
GLUT_KEY_F5 = Constant( 'GLUT_KEY_F5', 5)
GLUT_KEY_F6 = Constant( 'GLUT_KEY_F6', 6)
GLUT_KEY_F7 = Constant( 'GLUT_KEY_F7', 7)
GLUT_KEY_F8 = Constant( 'GLUT_KEY_F8', 8)
GLUT_KEY_F9 = Constant( 'GLUT_KEY_F9', 9)
GLUT_KEY_HOME = Constant( 'GLUT_KEY_HOME', 106)
GLUT_KEY_INSERT = Constant( 'GLUT_KEY_INSERT', 108)
GLUT_KEY_LEFT = Constant( 'GLUT_KEY_LEFT', 100)
GLUT_KEY_PAGE_DOWN = Constant( 'GLUT_KEY_PAGE_DOWN', 105)
GLUT_KEY_PAGE_UP = Constant( 'GLUT_KEY_PAGE_UP', 104)
GLUT_KEY_REPEAT_DEFAULT = Constant( 'GLUT_KEY_REPEAT_DEFAULT', 2)
GLUT_KEY_REPEAT_OFF = Constant( 'GLUT_KEY_REPEAT_OFF', 0)
GLUT_KEY_REPEAT_ON = Constant( 'GLUT_KEY_REPEAT_ON', 1)
GLUT_KEY_RIGHT = Constant( 'GLUT_KEY_RIGHT', 102)
GLUT_KEY_UP = Constant( 'GLUT_KEY_UP', 101)
GLUT_LAYER_IN_USE = Constant( 'GLUT_LAYER_IN_USE', 801)
GLUT_LEFT = Constant( 'GLUT_LEFT', 0)
GLUT_LEFT_BUTTON = Constant( 'GLUT_LEFT_BUTTON', 0)
GLUT_LUMINANCE = Constant( 'GLUT_LUMINANCE', 512)
GLUT_MENU_IN_USE = Constant( 'GLUT_MENU_IN_USE', 1)
GLUT_MENU_NOT_IN_USE = Constant( 'GLUT_MENU_NOT_IN_USE', 0)
GLUT_MENU_NUM_ITEMS = Constant( 'GLUT_MENU_NUM_ITEMS', 300)
GLUT_MIDDLE_BUTTON = Constant( 'GLUT_MIDDLE_BUTTON', 1)
GLUT_MULTISAMPLE = Constant( 'GLUT_MULTISAMPLE', 128)
GLUT_NORMAL = Constant( 'GLUT_NORMAL', 0)
GLUT_NORMAL_DAMAGED = Constant( 'GLUT_NORMAL_DAMAGED', 804)
GLUT_NOT_VISIBLE = Constant( 'GLUT_NOT_VISIBLE', 0)
GLUT_NUM_BUTTON_BOX_BUTTONS = Constant( 'GLUT_NUM_BUTTON_BOX_BUTTONS', 607)
GLUT_NUM_DIALS = Constant( 'GLUT_NUM_DIALS', 608)
GLUT_NUM_MOUSE_BUTTONS = Constant( 'GLUT_NUM_MOUSE_BUTTONS', 605)
GLUT_NUM_SPACEBALL_BUTTONS = Constant( 'GLUT_NUM_SPACEBALL_BUTTONS', 606)
GLUT_NUM_TABLET_BUTTONS = Constant( 'GLUT_NUM_TABLET_BUTTONS', 609)
GLUT_OVERLAY = Constant( 'GLUT_OVERLAY', 1)
GLUT_OVERLAY_DAMAGED = Constant( 'GLUT_OVERLAY_DAMAGED', 805)
GLUT_OVERLAY_POSSIBLE = Constant( 'GLUT_OVERLAY_POSSIBLE', 800)
GLUT_OWNS_JOYSTICK = Constant( 'GLUT_OWNS_JOYSTICK', 613)
GLUT_PARTIALLY_RETAINED = Constant( 'GLUT_PARTIALLY_RETAINED', 2)
GLUT_RED = Constant( 'GLUT_RED', 0)
GLUT_RGB = Constant( 'GLUT_RGB', 0)
GLUT_RGBA = Constant( 'GLUT_RGBA', 0)
GLUT_RIGHT_BUTTON = Constant( 'GLUT_RIGHT_BUTTON', 2)
GLUT_SCREEN_HEIGHT = Constant( 'GLUT_SCREEN_HEIGHT', 201)
GLUT_SCREEN_HEIGHT_MM = Constant( 'GLUT_SCREEN_HEIGHT_MM', 203)
GLUT_SCREEN_WIDTH = Constant( 'GLUT_SCREEN_WIDTH', 200)
GLUT_SCREEN_WIDTH_MM = Constant( 'GLUT_SCREEN_WIDTH_MM', 202)
GLUT_SINGLE = Constant( 'GLUT_SINGLE', 0)
GLUT_STENCIL = Constant( 'GLUT_STENCIL', 32)
GLUT_STEREO = Constant( 'GLUT_STEREO', 256)
GLUT_TRANSPARENT_INDEX = Constant( 'GLUT_TRANSPARENT_INDEX', 803)
GLUT_UP = Constant( 'GLUT_UP', 1)
GLUT_VIDEO_RESIZE_HEIGHT = Constant( 'GLUT_VIDEO_RESIZE_HEIGHT', 909)
GLUT_VIDEO_RESIZE_HEIGHT_DELTA = Constant( 'GLUT_VIDEO_RESIZE_HEIGHT_DELTA', 905)
GLUT_VIDEO_RESIZE_IN_USE = Constant( 'GLUT_VIDEO_RESIZE_IN_USE', 901)
GLUT_VIDEO_RESIZE_POSSIBLE = Constant( 'GLUT_VIDEO_RESIZE_POSSIBLE', 900)
GLUT_VIDEO_RESIZE_WIDTH = Constant( 'GLUT_VIDEO_RESIZE_WIDTH', 908)
GLUT_VIDEO_RESIZE_WIDTH_DELTA = Constant( 'GLUT_VIDEO_RESIZE_WIDTH_DELTA', 904)
GLUT_VIDEO_RESIZE_X = Constant( 'GLUT_VIDEO_RESIZE_X', 906)
GLUT_VIDEO_RESIZE_X_DELTA = Constant( 'GLUT_VIDEO_RESIZE_X_DELTA', 902)
GLUT_VIDEO_RESIZE_Y = Constant( 'GLUT_VIDEO_RESIZE_Y', 907)
GLUT_VIDEO_RESIZE_Y_DELTA = Constant( 'GLUT_VIDEO_RESIZE_Y_DELTA', 903)
GLUT_VISIBLE = Constant( 'GLUT_VISIBLE', 1)
GLUT_WINDOW_ACCUM_ALPHA_SIZE = Constant( 'GLUT_WINDOW_ACCUM_ALPHA_SIZE', 114)
GLUT_WINDOW_ACCUM_BLUE_SIZE = Constant( 'GLUT_WINDOW_ACCUM_BLUE_SIZE', 113)
GLUT_WINDOW_ACCUM_GREEN_SIZE = Constant( 'GLUT_WINDOW_ACCUM_GREEN_SIZE', 112)
GLUT_WINDOW_ACCUM_RED_SIZE = Constant( 'GLUT_WINDOW_ACCUM_RED_SIZE', 111)
GLUT_WINDOW_ALPHA_SIZE = Constant( 'GLUT_WINDOW_ALPHA_SIZE', 110)
GLUT_WINDOW_BLUE_SIZE = Constant( 'GLUT_WINDOW_BLUE_SIZE', 109)
GLUT_WINDOW_BUFFER_SIZE = Constant( 'GLUT_WINDOW_BUFFER_SIZE', 104)
GLUT_WINDOW_COLORMAP_SIZE = Constant( 'GLUT_WINDOW_COLORMAP_SIZE', 119)
GLUT_WINDOW_CURSOR = Constant( 'GLUT_WINDOW_CURSOR', 122)
GLUT_WINDOW_DEPTH_SIZE = Constant( 'GLUT_WINDOW_DEPTH_SIZE', 106)
GLUT_WINDOW_DOUBLEBUFFER = Constant( 'GLUT_WINDOW_DOUBLEBUFFER', 115)
GLUT_WINDOW_FORMAT_ID = Constant( 'GLUT_WINDOW_FORMAT_ID', 123)
GLUT_WINDOW_GREEN_SIZE = Constant( 'GLUT_WINDOW_GREEN_SIZE', 108)
GLUT_WINDOW_HEIGHT = Constant( 'GLUT_WINDOW_HEIGHT', 103)
GLUT_WINDOW_NUM_CHILDREN = Constant( 'GLUT_WINDOW_NUM_CHILDREN', 118)
GLUT_WINDOW_NUM_SAMPLES = Constant( 'GLUT_WINDOW_NUM_SAMPLES', 120)
GLUT_WINDOW_PARENT = Constant( 'GLUT_WINDOW_PARENT', 117)
GLUT_WINDOW_RED_SIZE = Constant( 'GLUT_WINDOW_RED_SIZE', 107)
GLUT_WINDOW_RGBA = Constant( 'GLUT_WINDOW_RGBA', 116)
GLUT_WINDOW_STENCIL_SIZE = Constant( 'GLUT_WINDOW_STENCIL_SIZE', 105)
GLUT_WINDOW_STEREO = Constant( 'GLUT_WINDOW_STEREO', 121)
GLUT_WINDOW_WIDTH = Constant( 'GLUT_WINDOW_WIDTH', 102)
GLUT_WINDOW_X = Constant( 'GLUT_WINDOW_X', 100)
GLUT_WINDOW_Y = Constant( 'GLUT_WINDOW_Y', 101)
GLUT_XLIB_IMPLEMENTATION = Constant( 'GLUT_XLIB_IMPLEMENTATION', 13)
__all__ = [
    'GLUT_ACCUM',
    'GLUT_ACTIVE_ALT',
    'GLUT_ACTIVE_CTRL',
    'GLUT_ACTIVE_SHIFT',
    'GLUT_ALPHA',
    'GLUT_API_VERSION',
    'GLUT_BLUE',
    'GLUT_CURSOR_BOTTOM_LEFT_CORNER',
    'GLUT_CURSOR_BOTTOM_RIGHT_CORNER',
    'GLUT_CURSOR_BOTTOM_SIDE',
    'GLUT_CURSOR_CROSSHAIR',
    'GLUT_CURSOR_CYCLE',
    'GLUT_CURSOR_DESTROY',
    'GLUT_CURSOR_FULL_CROSSHAIR',
    'GLUT_CURSOR_HELP',
    'GLUT_CURSOR_INFO',
    'GLUT_CURSOR_INHERIT',
    'GLUT_CURSOR_LEFT_ARROW',
    'GLUT_CURSOR_LEFT_RIGHT',
    'GLUT_CURSOR_LEFT_SIDE',
    'GLUT_CURSOR_NONE',
    'GLUT_CURSOR_RIGHT_ARROW',
    'GLUT_CURSOR_RIGHT_SIDE',
    'GLUT_CURSOR_SPRAY',
    'GLUT_CURSOR_TEXT',
    'GLUT_CURSOR_TOP_LEFT_CORNER',
    'GLUT_CURSOR_TOP_RIGHT_CORNER',
    'GLUT_CURSOR_TOP_SIDE',
    'GLUT_CURSOR_UP_DOWN',
    'GLUT_CURSOR_WAIT',
    'GLUT_DEPTH',
    'GLUT_DEVICE_IGNORE_KEY_REPEAT',
    'GLUT_DEVICE_KEY_REPEAT',
    'GLUT_DISPLAY_MODE_POSSIBLE',
    'GLUT_DOUBLE',
    'GLUT_DOWN',
    'GLUT_ELAPSED_TIME',
    'GLUT_ENTERED',
    'GLUT_FULLY_COVERED',
    'GLUT_FULLY_RETAINED',
    'GLUT_GAME_MODE_ACTIVE',
    'GLUT_GAME_MODE_DISPLAY_CHANGED',
    'GLUT_GAME_MODE_HEIGHT',
    'GLUT_GAME_MODE_PIXEL_DEPTH',
    'GLUT_GAME_MODE_POSSIBLE',
    'GLUT_GAME_MODE_REFRESH_RATE',
    'GLUT_GAME_MODE_WIDTH',
    'GLUT_GREEN',
    'GLUT_HAS_DIAL_AND_BUTTON_BOX',
    'GLUT_HAS_JOYSTICK',
    'GLUT_HAS_KEYBOARD',
    'GLUT_HAS_MOUSE',
    'GLUT_HAS_OVERLAY',
    'GLUT_HAS_SPACEBALL',
    'GLUT_HAS_TABLET',
    'GLUT_HIDDEN',
    'GLUT_INDEX',
    'GLUT_INIT_DISPLAY_MODE',
    'GLUT_INIT_STATE',
    'GLUT_INIT_WINDOW_HEIGHT',
    'GLUT_INIT_WINDOW_WIDTH',
    'GLUT_INIT_WINDOW_X',
    'GLUT_INIT_WINDOW_Y',
    'GLUT_JOYSTICK_AXES',
    'GLUT_JOYSTICK_BUTTONS',
    'GLUT_JOYSTICK_BUTTON_A',
    'GLUT_JOYSTICK_BUTTON_B',
    'GLUT_JOYSTICK_BUTTON_C',
    'GLUT_JOYSTICK_BUTTON_D',
    'GLUT_JOYSTICK_POLL_RATE',
    'GLUT_KEY_DOWN',
    'GLUT_KEY_END',
    'GLUT_KEY_F1',
    'GLUT_KEY_F10',
    'GLUT_KEY_F11',
    'GLUT_KEY_F12',
    'GLUT_KEY_F2',
    'GLUT_KEY_F3',
    'GLUT_KEY_F4',
    'GLUT_KEY_F5',
    'GLUT_KEY_F6',
    'GLUT_KEY_F7',
    'GLUT_KEY_F8',
    'GLUT_KEY_F9',
    'GLUT_KEY_HOME',
    'GLUT_KEY_INSERT',
    'GLUT_KEY_LEFT',
    'GLUT_KEY_PAGE_DOWN',
    'GLUT_KEY_PAGE_UP',
    'GLUT_KEY_REPEAT_DEFAULT',
    'GLUT_KEY_REPEAT_OFF',
    'GLUT_KEY_REPEAT_ON',
    'GLUT_KEY_RIGHT',
    'GLUT_KEY_UP',
    'GLUT_LAYER_IN_USE',
    'GLUT_LEFT',
    'GLUT_LEFT_BUTTON',
    'GLUT_LUMINANCE',
    'GLUT_MENU_IN_USE',
    'GLUT_MENU_NOT_IN_USE',
    'GLUT_MENU_NUM_ITEMS',
    'GLUT_MIDDLE_BUTTON',
    'GLUT_MULTISAMPLE',
    'GLUT_NORMAL',
    'GLUT_NORMAL_DAMAGED',
    'GLUT_NOT_VISIBLE',
    'GLUT_NUM_BUTTON_BOX_BUTTONS',
    'GLUT_NUM_DIALS',
    'GLUT_NUM_MOUSE_BUTTONS',
    'GLUT_NUM_SPACEBALL_BUTTONS',
    'GLUT_NUM_TABLET_BUTTONS',
    'GLUT_OVERLAY',
    'GLUT_OVERLAY_DAMAGED',
    'GLUT_OVERLAY_POSSIBLE',
    'GLUT_OWNS_JOYSTICK',
    'GLUT_PARTIALLY_RETAINED',
    'GLUT_RED',
    'GLUT_RGB',
    'GLUT_RGBA',
    'GLUT_RIGHT_BUTTON',
    'GLUT_SCREEN_HEIGHT',
    'GLUT_SCREEN_HEIGHT_MM',
    'GLUT_SCREEN_WIDTH',
    'GLUT_SCREEN_WIDTH_MM',
    'GLUT_SINGLE',
    'GLUT_STENCIL',
    'GLUT_STEREO',
    'GLUT_TRANSPARENT_INDEX',
    'GLUT_UP',
    'GLUT_VIDEO_RESIZE_HEIGHT',
    'GLUT_VIDEO_RESIZE_HEIGHT_DELTA',
    'GLUT_VIDEO_RESIZE_IN_USE',
    'GLUT_VIDEO_RESIZE_POSSIBLE',
    'GLUT_VIDEO_RESIZE_WIDTH',
    'GLUT_VIDEO_RESIZE_WIDTH_DELTA',
    'GLUT_VIDEO_RESIZE_X',
    'GLUT_VIDEO_RESIZE_X_DELTA',
    'GLUT_VIDEO_RESIZE_Y',
    'GLUT_VIDEO_RESIZE_Y_DELTA',
    'GLUT_VISIBLE',
    'GLUT_WINDOW_ACCUM_ALPHA_SIZE',
    'GLUT_WINDOW_ACCUM_BLUE_SIZE',
    'GLUT_WINDOW_ACCUM_GREEN_SIZE',
    'GLUT_WINDOW_ACCUM_RED_SIZE',
    'GLUT_WINDOW_ALPHA_SIZE',
    'GLUT_WINDOW_BLUE_SIZE',
    'GLUT_WINDOW_BUFFER_SIZE',
    'GLUT_WINDOW_COLORMAP_SIZE',
    'GLUT_WINDOW_CURSOR',
    'GLUT_WINDOW_DEPTH_SIZE',
    'GLUT_WINDOW_DOUBLEBUFFER',
    'GLUT_WINDOW_FORMAT_ID',
    'GLUT_WINDOW_GREEN_SIZE',
    'GLUT_WINDOW_HEIGHT',
    'GLUT_WINDOW_NUM_CHILDREN',
    'GLUT_WINDOW_NUM_SAMPLES',
    'GLUT_WINDOW_PARENT',
    'GLUT_WINDOW_RED_SIZE',
    'GLUT_WINDOW_RGBA',
    'GLUT_WINDOW_STENCIL_SIZE',
    'GLUT_WINDOW_STEREO',
    'GLUT_WINDOW_WIDTH',
    'GLUT_WINDOW_X',
    'GLUT_WINDOW_Y',
    'GLUT_XLIB_IMPLEMENTATION'
]



'''OpenGL extension ATI.element_array

This module customises the behaviour of the 
OpenGL.raw.GL.ATI.element_array to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism for an application to create
	an array of index data for use in specifying geometric primitives.
	
	This extension is most useful when used in conjunction with the
	ATI_vertex_array_object extension. ATI_vertex_array_object
	provides an interface for storing vertex array data in persistent,
	hardware-addressable memory. In cases where large amounts of
	vertex data are in use, the index data used to construct
	primitives (typically as passed to the GL through DrawElements)
	can impose a significant bandwidth burden. ATI_element_array
	allows the application to specify independent arrays of elements,
	which can then be cached using ATI_vertex_array_object.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ATI/element_array.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ATI.element_array import *
from OpenGL.raw.GL.ATI.element_array import _EXTENSION_NAME

def glInitElementArrayATI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glElementPointerATI.pointer size not checked against 'type'
glElementPointerATI=wrapper.wrapper(glElementPointerATI).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION